@@ -310,9 +310,11 @@ MessageFactory::MessageReply MessageFactory::createReply()
         parser.setIdentityManager(m_identityManager);
         parser.setCharsets(MessageComposerSettings::self()->preferredCharsets());
         parser.setWordWrap(MessageComposerSettings::wordWrap(), MessageComposerSettings::lineWrapWidth());
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 1)
         if (MessageComposer::MessageComposerSettings::quoteSelectionOnly()) {
             parser.setSelection(m_selection);
         }
+#endif
         parser.setAllowDecryption(true);
         if (!m_template.isEmpty()) {
             parser.process(m_template, m_origMsg);
@@ -955,7 +957,7 @@ QString MessageFactory::replaceHeadersInString(const KMime::Message::Ptr &msg, c
 
     idx = 0;
     while ((idx = rx.indexIn(result, idx)) != -1) {
-        QString replacement = msg->headerByType(rx.cap(1).toLatin1()) ? msg->headerByType(rx.cap(1).toLatin1())->asUnicodeString() : QStringLiteral("");
+        QString replacement = msg->headerByType(rx.cap(1).toLatin1().constData()) ? msg->headerByType(rx.cap(1).toLatin1().constData())->asUnicodeString() : QStringLiteral("");
         result.replace(idx, rx.matchedLength(), replacement);
         idx += replacement.length();
     }
