@@ -293,153 +293,6 @@ QString generateMessageId(const QString &address, const QString &suffix)
     return msgIdStr;
 }
 
-QString stripEmailAddr(const QString &aStr)
-{
-    //qCDebug(MESSAGECORE_LOG) << "(" << aStr << ")";
-
-    if (aStr.isEmpty()) {
-        return QString();
-    }
-
-    QString result;
-
-    // The following is a primitive parser for a mailbox-list (cf. RFC 2822).
-    // The purpose is to extract a displayable string from the mailboxes.
-    // Comments in the addr-spec are not handled. No error checking is done.
-
-    QString name;
-    QString comment;
-    QString angleAddress;
-    enum { TopLevel, InComment, InAngleAddress } context = TopLevel;
-    bool inQuotedString = false;
-    int commentLevel = 0;
-
-    QChar ch;
-    int strLength(aStr.length());
-    for (int index = 0; index < strLength; ++index) {
-        ch = aStr[index];
-        switch (context) {
-        case TopLevel : {
-            switch (ch.toLatin1()) {
-            case '"' : inQuotedString = !inQuotedString;
-                break;
-            case '(' : if (!inQuotedString) {
-                    context = InComment;
-                    commentLevel = 1;
-                } else {
-                    name += ch;
-                }
-                break;
-            case '<' : if (!inQuotedString) {
-                    context = InAngleAddress;
-                } else {
-                    name += ch;
-                }
-                break;
-            case '\\' : // quoted character
-                ++index; // skip the '\'
-                if (index < aStr.length()) {
-                    name += aStr[index];
-                }
-                break;
-            case ',' : if (!inQuotedString) {
-                    // next email address
-                    if (!result.isEmpty()) {
-                        result += QLatin1String(", ");
-                    }
-                    name = name.trimmed();
-                    comment = comment.trimmed();
-                    angleAddress = angleAddress.trimmed();
-                    if (angleAddress.isEmpty() && !comment.isEmpty()) {
-                        // handle Outlook-style addresses like
-                        // john.doe@invalid (John Doe)
-                        result += comment;
-                    } else if (!name.isEmpty()) {
-                        result += name;
-                    } else if (!comment.isEmpty()) {
-                        result += comment;
-                    } else if (!angleAddress.isEmpty()) {
-                        result += angleAddress;
-                    }
-                    name.clear();
-                    comment.clear();
-                    angleAddress.clear();
-                } else {
-                    name += ch;
-                }
-                break;
-            default :  name += ch;
-            }
-            break;
-        }
-        case InComment : {
-            switch (ch.toLatin1()) {
-            case '(' : ++commentLevel;
-                comment += ch;
-                break;
-            case ')' : --commentLevel;
-                if (commentLevel == 0) {
-                    context = TopLevel;
-                    comment += QLatin1Char(' '); // separate the text of several comments
-                } else {
-                    comment += ch;
-                }
-                break;
-            case '\\' : // quoted character
-                ++index; // skip the '\'
-                if (index < aStr.length()) {
-                    comment += aStr[index];
-                }
-                break;
-            default :  comment += ch;
-            }
-            break;
-        }
-        case InAngleAddress : {
-            switch (ch.toLatin1()) {
-            case '"' : inQuotedString = !inQuotedString;
-                angleAddress += ch;
-                break;
-            case '>' : if (!inQuotedString) {
-                    context = TopLevel;
-                } else {
-                    angleAddress += ch;
-                }
-                break;
-            case '\\' : // quoted character
-                ++index; // skip the '\'
-                if (index < aStr.length()) {
-                    angleAddress += aStr[index];
-                }
-                break;
-            default :  angleAddress += ch;
-            }
-            break;
-        }
-        } // switch ( context )
-    }
-    if (!result.isEmpty()) {
-        result += QLatin1String(", ");
-    }
-    name = name.trimmed();
-    comment = comment.trimmed();
-    angleAddress = angleAddress.trimmed();
-    if (angleAddress.isEmpty() && !comment.isEmpty()) {
-        // handle Outlook-style addresses like
-        // john.doe@invalid (John Doe)
-        result += comment;
-    } else if (!name.isEmpty()) {
-        result += name;
-    } else if (!comment.isEmpty()) {
-        result += comment;
-    } else if (!angleAddress.isEmpty()) {
-        result += angleAddress;
-    }
-
-    //qCDebug(MESSAGECORE_LOG) << "Returns \"" << result << "\"";
-    return result;
-}
-
 QString quoteHtmlChars(const QString &str, bool removeLineBreaks)
 {
     QString result;
@@ -533,14 +386,16 @@ QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList,
     QString result;
     int numberAddresses = 0;
     bool expandableInserted = false;
-    KIdentityManagement::IdentityManager *im = new KIdentityManagement::IdentityManager(true);
+    KIdentityManagement::IdentityManager im(true);
 
     foreach (const KMime::Types::Mailbox &mailbox, mailboxList) {
         if (!mailbox.prettyAddress().isEmpty()) {
             numberAddresses++;
             if (expandable == ExpandableAddresses && !expandableInserted && numberAddresses > collapseNumber) {
                 result = QLatin1String("<span id=\"icon") + fieldName + QLatin1String("\"></span>") + result;
-                result += QLatin1String("<span id=\"dots") + fieldName + QLatin1String("\">...</span><span id=\"hidden") + fieldName + QLatin1String("\">");
+                const QString visibility = QStringLiteral(" style=\"display:none;\"");
+
+                result += QLatin1String("<span id=\"dots") + fieldName + QLatin1String("\">...</span><span id=\"hidden") + fieldName + QLatin1String("\")") + visibility + QLatin1String(">");
                 expandableInserted = true;
             }
 
@@ -549,7 +404,7 @@ QString emailAddrAsAnchor(const KMime::Types::Mailbox::List &mailboxList,
                           + QString::fromLatin1(QUrl::toPercentEncoding(KEmailAddress::encodeMailtoUrl(mailbox.prettyAddress(KMime::Types::Mailbox::QuoteWhenNecessary)).path()))
                           + QLatin1String("\" ") + cssStyle + QLatin1Char('>');
             }
-            const bool foundMe = (im->identities().count() == 1) && (im->identityForAddress(mailbox.prettyAddress()) != KIdentityManagement::Identity::null());
+            const bool foundMe = (im.identities().count() == 1) && (im.identityForAddress(mailbox.prettyAddress()) != KIdentityManagement::Identity::null());
             const QString i18nMe = i18nc("signal that this email is defined in my identity", "Me");
             if (display == DisplayNameOnly) {
                 if (!mailbox.name().isEmpty()) { // Fallback to the email address when the name is not set.
