@@ -85,6 +85,8 @@ public:
 View::View(Widget *pParent)
     : QTreeView(pParent), d(new Private(this, pParent))
 {
+    setFocusPolicy(Qt::NoFocus);
+
     d->mSaveThemeColumnStateTimer = new QTimer();
     connect(d->mSaveThemeColumnStateTimer, &QTimer::timeout, this, &View::saveThemeColumnState);
 
@@ -555,7 +557,7 @@ void View::applyThemeColumns()
             (*it)->setCurrentWidth(columnWidth);
             //Laurent Bug 358855 - message list column widths lost when program closed
             // I need to investigate if this code is still necessary (all method)
-            //header()->resizeSection(idx, columnWidth);
+            header()->resizeSection(idx, columnWidth);
         } else {
             (*it)->setCurrentWidth(-1);
         }
@@ -2414,12 +2416,12 @@ bool View::event(QEvent *e)
                 "</tr>");
 
         if (textIsLeftToRight) {
-            tip += htmlCodeForStandardRow.arg(i18n("From")).arg(MessageCore::StringUtil::stripEmailAddr(mi->sender()));
-            tip += htmlCodeForStandardRow.arg(i18nc("Receiver of the email", "To")).arg(MessageCore::StringUtil::stripEmailAddr(mi->receiver()));
+            tip += htmlCodeForStandardRow.arg(i18n("From")).arg(mi->displaySender());
+            tip += htmlCodeForStandardRow.arg(i18nc("Receiver of the email", "To")).arg(mi->displayReceiver());
             tip += htmlCodeForStandardRow.arg(i18n("Date")).arg(mi->formattedDate());
         } else {
-            tip += htmlCodeForStandardRow.arg(MessageCore::StringUtil::stripEmailAddr(mi->sender())).arg(i18n("From"));
-            tip += htmlCodeForStandardRow.arg(MessageCore::StringUtil::stripEmailAddr(mi->receiver())).arg(i18nc("Receiver of the email", "To"));
+            tip += htmlCodeForStandardRow.arg(mi->displaySender()).arg(i18n("From"));
+            tip += htmlCodeForStandardRow.arg(mi->displayReceiver()).arg(i18nc("Receiver of the email", "To"));
             tip += htmlCodeForStandardRow.arg(mi->formattedDate(), i18n("Date"));
         }
 
@@ -2458,7 +2460,7 @@ bool View::event(QEvent *e)
         }
 
         tip += QLatin1String(
-                   "</table" \
+                   "</table>" \
                    "</td>" \
                    "</tr>"
                );
