@@ -21,14 +21,17 @@
 #include "csshelper.h"
 #include "bodypartformatterfactorysingleton.h"
 
+#include <MimeTreeParser/BodyPartFormatter>
+#include "messagepartthemes/default/defaultrenderer.h"
+
 #include "viewer/viewer_p.h"
 #include "widgets/htmlstatusbar.h"
 #include "settings/messageviewersettings.h"
 
-namespace MessageViewer
-{
+using namespace MessageViewer;
+
 MailViewerSource::MailViewerSource(ViewerPrivate *viewer) :
-    ObjectTreeSourceIf(), mViewer(viewer)
+    MimeTreeParser::Interface::ObjectTreeSource(), mViewer(viewer)
 {
 }
 
@@ -56,7 +59,7 @@ bool MailViewerSource::showSignatureDetails() const
     return mViewer->mShowSignatureDetails;
 }
 
-void MailViewerSource::setHtmlMode(Util::HtmlMode mode)
+void MailViewerSource::setHtmlMode(MimeTreeParser::Util::HtmlMode mode)
 {
     mViewer->mColorBar->setMode(mode);
 }
@@ -81,21 +84,16 @@ QObject *MailViewerSource::sourceObject()
     return mViewer;
 }
 
-const AttachmentStrategy *MailViewerSource::attachmentStrategy()
+const MimeTreeParser::AttachmentStrategy *MailViewerSource::attachmentStrategy()
 {
     return mViewer->attachmentStrategy();
 }
 
-HtmlWriter *MailViewerSource::htmlWriter()
+MimeTreeParser::HtmlWriter *MailViewerSource::htmlWriter()
 {
     return mViewer->htmlWriter();
 }
 
-CSSHelperBase *MailViewerSource::cssHelper()
-{
-    return mViewer->cssHelper();
-}
-
 bool MailViewerSource::autoImportKeys() const
 {
     return MessageViewer::MessageViewerSettings::self()->autoImportKeys();
@@ -111,8 +109,12 @@ bool MailViewerSource::showExpandQuotesMark() const
     return MessageViewer::MessageViewerSettings::self()->showExpandQuotesMark();
 }
 
-const BodyPartFormatterBaseFactory *MailViewerSource::bodyPartFormatterFactory()
+const MimeTreeParser::BodyPartFormatterBaseFactory *MailViewerSource::bodyPartFormatterFactory()
 {
     return bodyPartFormatterBaseFactoryInstance();
 }
-}
+
+MimeTreeParser::Interface::MessagePartRendererPtr MailViewerSource::messagePartTheme(MimeTreeParser::Interface::MessagePart::Ptr msgPart)
+{
+    return  MimeTreeParser::Interface::MessagePartRenderer::Ptr(new DefaultRenderer(msgPart, mViewer->cssHelper()));
+}
\ No newline at end of file
