@@ -23,10 +23,11 @@
 #define MESSAGEVIEWER_H
 
 #include "messageviewer_export.h"
+#include "config-messageviewer.h"
 #include "messageviewer/viewerplugininterface.h"
-#include "messageviewer/enums.h"
+#include <MimeTreeParser/Enums>
 
-#include <kmime/kmime_message.h>
+#include <KMime/Message>
 
 #include <QWidget>
 
@@ -36,6 +37,11 @@ class Item;
 class ItemFetchJob;
 }
 
+namespace MimeTreeParser
+{
+class AttachmentStrategy;
+}
+
 class KActionCollection;
 class QAction;
 class KToggleAction;
@@ -46,10 +52,16 @@ class QCloseEvent;
 class QEvent;
 class QResizeEvent;
 
+namespace WebEngineViewer
+{
+class WebHitTestResult;
+}
+
 namespace MessageViewer
 {
+class WebHitTestResult;
+
 class HeaderStylePlugin;
-class AttachmentStrategy;
 class CSSHelper;
 class ViewerPrivate;
 
@@ -93,8 +105,7 @@ public:
     * @param actionCollection the action collection where the widget's actions will belong to
     * @param f window flags
     */
-    explicit Viewer(QWidget *parent, QWidget *widget = Q_NULLPTR, KActionCollection *actionCollection = Q_NULLPTR,
-                    Qt::WindowFlags f = 0);
+    explicit Viewer(QWidget *parent, QWidget *widget = Q_NULLPTR, KActionCollection *actionCollection = Q_NULLPTR);
     virtual ~Viewer();
 
     /**
@@ -147,7 +158,7 @@ public:
     * @param msg - the message to be shown. If 0, an empty page is displayed.
     * @param updateMode - update the display immediately or not. See UpdateMode.
     */
-    void setMessage(const KMime::Message::Ptr &message, UpdateMode updateMode = Delayed);
+    void setMessage(const KMime::Message::Ptr &message, MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
 
     /**
     * Set the Akonadi item that will be displayed.
@@ -155,7 +166,7 @@ public:
     *               an empty page is shown.
     * @param updateMode - update the display immediately or not. See UpdateMode.
     */
-    void setMessageItem(const Akonadi::Item &item, UpdateMode updateMode = Delayed);
+    void setMessageItem(const Akonadi::Item &item, MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
 
     /**
     * The path to the message in terms of Akonadi collection hierarchy.
@@ -178,9 +189,9 @@ public:
     * returned by message() to 0.
     * @param updateMode - update the display immediately or not. See UpdateMode.
     */
-    void clear(UpdateMode updateMode = Delayed);
+    void clear(MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
 
-    void update(UpdateMode updateMode = Delayed);
+    void update(MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
 
     /**
     * Sets a message as the current one and print it immediately.
@@ -212,18 +223,12 @@ public:
     /** Is loading ext. references to be supported? Takes into account override */
     bool htmlLoadExternal() const;
 
-    /**
-    * Set the application name that is shown when the splash screen is active.
-    * @param appName - A QString that is set to the calling application name.
-    */
-    void setAppName(const QString &appName);
-
     /**
     * Display a generic HTML splash page instead of a message.
     * @param templateName - the template to be loaded
     * @param data - data for the template
     */
-    void displaySplashPage(const QString &templateName, const QVariantHash &data);
+    void displaySplashPage(const QString &templateName, const QVariantHash &data, const QByteArray &domain = QByteArray());
 
     /** Enable the displaying of messages again after an splash (or other) page was displayed */
     void enableMessageDisplay();
@@ -239,18 +244,12 @@ public:
     /** Enforce message decryption. */
     void setDecryptMessageOverwrite(bool overwrite = true);
 
-    /**
-    * Get an instance for the configuration widget. The caller has the ownership and must delete the widget. See also configObject();
-    * The caller should also call the widget's slotSettingsChanged() if the configuration has changed.
-    */
-    QWidget *configWidget();
-
     /**
     * Initiates a delete, by sending a signal to delete the message item */
     void deleteMessage();
 
-    const AttachmentStrategy *attachmentStrategy() const;
-    void setAttachmentStrategy(const AttachmentStrategy *strategy);
+    const MimeTreeParser::AttachmentStrategy *attachmentStrategy() const;
+    void setAttachmentStrategy(const MimeTreeParser::AttachmentStrategy *strategy);
 
     QString overrideEncoding() const;
     void setOverrideEncoding(const QString &encoding);
@@ -258,14 +257,10 @@ public:
     void setPrinting(bool enable);
 
     void selectAll();
-    void clearSelection();
     void copySelectionToClipboard();
 
     void setZoomFactor(qreal zoomFactor);
 
-    void setZoomTextOnly(bool textOnly);
-    bool zoomTextOnly() const;
-
     KToggleAction *toggleFixFontAction() const;
 
     KToggleAction *toggleMimePartTreeAction() const;
@@ -281,8 +276,6 @@ public:
     QAction *saveAsAction() const;
     QAction *saveMessageDisplayFormatAction() const;
     QAction *resetMessageDisplayFormatAction() const;
-    QAction *blockImage() const;
-    QAction *openBlockableItems() const;
     KActionMenu *shareServiceUrlMenu() const;
     HeaderStylePlugin *headerStylePlugin() const;
     void setPluginName(const QString &pluginName);
@@ -322,12 +315,13 @@ public:
     void setExternalWindow(bool b);
 
     void saveMainFrameScreenshotInFile(const QString &filename);
-    bool adblockEnabled() const;
     bool mimePartTreeIsEmpty() const;
 
     void showOpenAttachmentFolderWidget(const QUrl &url);
     QList<QAction *> viewerPluginActionList(MessageViewer::ViewerPluginInterface::SpecificFeatureTypes features);
+    QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
 
+    void runJavaScript(const QString &code);
 Q_SIGNALS:
     void moveMessageToTrash();
     void executeMailAction(MessageViewer::Viewer::MailAction type);
@@ -346,7 +340,7 @@ Q_SIGNALS:
 
     /** The user presses the right mouse button. 'url' may be 0. */
     void popupMenu(const Akonadi::Item &msg, const QUrl &url, const QUrl &imageUrl, const QPoint &mousePos);
-
+    void displayPopupMenu(const Akonadi::Item &msg, const WebEngineViewer::WebHitTestResult &result, const QPoint &mousePos);
     /**
     * The message viewer handles some types of urls itself, most notably http(s)
     * and ftp(s). When it can't handle the url it will Q_EMIT this signal.
