@@ -21,7 +21,8 @@
 #ifndef MAILVIEWER_P_H
 #define MAILVIEWER_P_H
 
-#include "messageviewer/nodehelper.h"
+#include <MimeTreeParser/NodeHelper>
+#include "config-messageviewer.h"
 #include "viewer.h" //not so nice, it is actually for the enums from MailViewer
 #include "PimCommon/ShareServiceUrlManager"
 #include "messageviewer/viewerplugininterface.h"
@@ -29,7 +30,7 @@
 #include <AkonadiCore/item.h>
 #include <AkonadiCore/monitor.h>
 #include <kio/job.h>
-#include <kmime/kmime_message.h>
+#include <KMime/Message>
 #include <kservice.h>
 #include <ksharedconfig.h>
 #include <QUrl>
@@ -63,24 +64,32 @@ namespace PimCommon
 class ShareServiceUrlManager;
 }
 
+namespace MimeTreeParser
+{
+class AttachmentStrategy;
+class HtmlWriter;
+class ObjectTreeParser;
+}
+
+namespace WebEngineViewer
+{
+class WebHitTestResult;
+class FindBarWebEngineView;
+class ZoomActionMenu;
+}
 namespace MessageViewer
 {
 class HeaderStylePlugin;
-class HtmlWriter;
 class CSSHelper;
-class AttachmentStrategy;
-class ObjectTreeParser;
-class FindBarWebView;
-class WebKitPartHtmlWriter;
+class MailWebEngineView;
+class WebEnginePartHtmlWriter;
 class HtmlStatusBar;
-class MailWebView;
 class ScamDetectionWarningWidget;
 class MimePartTreeView;
 class OpenAttachmentFolderWidget;
 class HeaderStyleMenuManager;
 class ViewerPluginToolManager;
 class ViewerPluginInterface;
-class ZoomActionMenu;
 /**
 \brief Private class for the Viewer, the main widget in the messageviewer library.
 
@@ -103,23 +112,22 @@ automatically updated on external changes.
 Once a message is set, update() is called. update() can also be called after the message has already
 been displayed. As an example, this is the case when the user decides to decrypt the message. The
 decryption can happen async, and once the decryption is finished, update() is called to display the
-now decrypted content. See the documentation of ObjectTreeParser on how exactly decryption is
+now decrypted content. See the documentation of MimeTreeParser::ObjectTreeParser on how exactly decryption is
 handled.
 update() is just a thin wrapper that calls updateReaderWin(). The only difference is that update()
 has a timer that prevents too many slow calls to updateReaderWin() in a short time frame.
 updateReaderWin() again is only a thin wrapper that resets some state and then calls
 displayMessage().
-displayMessage() itself is again a thin wrapper, which starts the HtmlWriter and then calls
+displayMessage() itself is again a thin wrapper, which starts the MimeTreeParser::HtmlWriter and then calls
 parseMsg().
-Finally, parseMsg() does the real work. It uses ObjectTreeParser::parseObjectTree() to let the
-ObjectTreeParser parse the message and generate the HTML code for it.
-As mentioned before, it can happen that the ObjectTreeParser needs to do some operation that happens
-async, for example decrypting. In this case, the ObjectTreeParser will create a BodyPartMemento,
+Finally, parseMsg() does the real work. It uses MimeTreeParser::ObjectTreeParser ::parseObjectTree() to let the
+MimeTreeParser::ObjectTreeParser parse the message and generate the HTML code for it.
+As mentioned before, it can happen that the MimeTreeParser::ObjectTreeParser needs to do some operation that happens
+async, for example decrypting. In this case, the MimeTreeParser::ObjectTreeParser will create a BodyPartMemento,
 which basically is a wrapper around the job that does the async operation. Once the async operation
 is finished. the BodyPartMemento will trigger an update() of ViewerPrivate, so that
-ObjectTreeParser::parseObjectTree() gets called again and the ObjectTreeParser then can generate
-HTML which has the decrypted content of the message. Again, see the documentation of ObjectTreeParser
-for the details.
+MimeTreeParser::ObjectTreeParser ::parseObjectTree() gets called again and the MimeTreeParser::ObjectTreeParser then can generate
+HTML which has the decrypted content of the message. Again, see the documentation of MimeTreeParser::ObjectTreeParser for the details.
 Additionally, parseMsg() does some evil hack for saving unencrypted messages should the config
 option for that be set.
 
@@ -143,9 +151,9 @@ ItemModifyJob to store the changes of the attachment. A map of currently active
 their KMime::Content is available in mEditorWatchers.
 For most attachment actions, the attachment is first written to a temp file. The action is then
 executed on this temp file. Writing the attachment to a temp file is done with
-NodeHelper::writeNodeToTempFile(). This method is called before opening or copying an attachment or
-when rendering the attachment list. The ObjectTreeParser also calls NodeHelper::writeNodeToTempFile()
-in some places. Once the temp file is written, NodeHelper::tempFileUrlFromNode() can be used to get
+MimeTreeParser::NodeHelper::writeNodeToTempFile(). This method is called before opening or copying an attachment or
+when rendering the attachment list. The MimeTreeParser::ObjectTreeParser also calls MimeTreeParser::NodeHelper::writeNodeToTempFile()
+in some places. Once the temp file is written, MimeTreeParser::NodeHelper::tempFileUrlFromNode() can be used to get
 the file name of the temp file for a specific MIME part. This is for example used by the handler for
 'attachment:' URLs, AttachmentURLHandler.
 
@@ -153,7 +161,7 @@ Since URLs for attachments are in the "attachment:" scheme, dragging them as-is
 wouldn't work, since other applications don't understand this scheme. Therefore, the viewer has
 special handling for dragging URLs: In eventFilter(), drags are detected, and the URL handler is
 called to deal with the drag. The attachment URL handler then starts a drag with the file:// URL
-of the temp file of the attachment, which it gets with NodeHelper::tempFileUrlFromNode().
+of the temp file of the attachment, which it gets with MimeTreeParser::NodeHelper::tempFileUrlFromNode().
 
 TODO: How are attachment handled that are loaded on demand? How does prepareHandleAttachment() work?
 TODO: This temp file handling is a big mess and could use a rewrite, especially in the face of load
@@ -163,19 +171,19 @@ Some header styles display an attachment list in the header. The HTML code for t
 cannot be generated by the HeaderStyle itself, since that does not know about all attachments.
 Therefore, the attachment list needs to be created by ViewerPrivate. For this, the HeaderStyle
 writes out a placeholder for the attachment list when it creates the HTML for the header. Once the
-ObjectTreeParser is finished with the message, injectAttachments() is called. injectAttachments()
+MimeTreeParser::ObjectTreeParser is finished with the message, injectAttachments() is called. injectAttachments()
 searches for the placeholder and replaces that with the real HTML code for the attachments.
 
 One of the attachment actions is to scoll to the attachment. That action is only available when
 right-clicking the header. The action scrolls to the attachment in the body and draws a yellow frame
 around the attachment. This is done in scrollToAttachment(). The attachment in the body and the div
-which is used for the colored frame are both created by the ObjectTreeParser.
+which is used for the colored frame are both created by the MimeTreeParser::ObjectTreeParser .
 
 \par Misc
 
-ViewerPrivate holds the NodeHelper, which is passed on to the ObjectTreeParser when it needs it.
-It also holds the HeaderStyle, HeaderStrategy, AttachmentStrategy, CSSHelper, HtmlWriter and more,
-some of them again passed to the ObjectTreeParser when it needs it.
+ViewerPrivate holds the MimeTreeParser::NodeHelper, which is passed on to the MimeTreeParser::ObjectTreeParser when it needs it.
+It also holds the HeaderStyle, HeaderStrategy, MimeTreeParser::AttachmentStrategy, CSSHelper, MimeTreeParser::HtmlWriter and more,
+some of them again passed to the MimeTreeParser::ObjectTreeParser when it needs it.
 
 @author andras@kdab.net
  */
@@ -195,7 +203,7 @@ public:
     /** Open the attachment pointed to the node.
     * @param fileName - if not empty, use this file to load the attachment content
     */
-    void openAttachment(KMime::Content *node, const QString &fileName);
+    void openAttachment(KMime::Content *node, const QUrl &url);
 
     /** Delete the attachment the @param node points to. Returns false if the user
     cancelled the deletion, true in all other cases (including failure to delete
@@ -209,9 +217,7 @@ public:
     cancelled the editing, true in all other cases! */
     void editAttachment(KMime::Content *node, bool showWarning = true);
 
-    /** Access to the MailWebView used for the viewer. Use with
-      care! */
-    MailWebView *htmlPart() const;
+    void scrollToAnchor(const QString &anchor);
 
     void showAttachmentPopup(KMime::Content *node, const QString &name, const QPoint &p);
 
@@ -220,9 +226,9 @@ public:
     * to the given values.
     * Call this so that slotHandleAttachment() knows which attachment to handle.
     */
-    void prepareHandleAttachment(KMime::Content *node, const QString &fileName);
+    void prepareHandleAttachment(KMime::Content *node);
 
-    void postProcessMessage(ObjectTreeParser *otp, KMMsgEncryptionState encryptionState);
+    void postProcessMessage(MimeTreeParser::ObjectTreeParser *otp, MimeTreeParser::KMMsgEncryptionState encryptionState);
 
     QString createAtmFileLink(const QString &atmFileName) const;
     KService::Ptr getServiceOffer(KMime::Content *content);
@@ -230,14 +236,14 @@ public:
     void attachmentOpenWith(KMime::Content *node, const KService::Ptr &offer = KService::Ptr());
     void attachmentOpen(KMime::Content *node);
 
-    /** Return the HtmlWriter connected to the MailWebView we use */
-    HtmlWriter *htmlWriter() const;
+    /** Return the MimeTreeParser::HtmlWriter connected to the MailWebView we use */
+    MimeTreeParser::HtmlWriter *htmlWriter() const;
 
     HeaderStylePlugin *headerStylePlugin() const;
 
     CSSHelper *cssHelper() const;
 
-    NodeHelper *nodeHelper() const;
+    MimeTreeParser::NodeHelper *nodeHelper() const;
 
     Viewer *viewer() const;
 
@@ -248,11 +254,8 @@ public:
     /** Returns whether the message should be decryted. */
     bool decryptMessage() const;
 
-    /** Calculate the pixel size */
-    int pointsToPixel(int pointSize) const;
-
     /** Display a generic HTML splash page instead of a message. */
-    void displaySplashPage(const QString &templateName, const QVariantHash &data);
+    void displaySplashPage(const QString &templateName, const QVariantHash &data, const QByteArray &domain = QByteArray());
 
     void displaySplashPage(const QString &message);
 
@@ -293,8 +296,8 @@ public:
     void writeConfig(bool withSync = true);
 
     /** Get/set the message attachment strategy. */
-    const AttachmentStrategy *attachmentStrategy() const;
-    void setAttachmentStrategy(const AttachmentStrategy *strategy);
+    const MimeTreeParser::AttachmentStrategy *attachmentStrategy() const;
+    void setAttachmentStrategy(const MimeTreeParser::AttachmentStrategy *strategy);
 
     /** Get selected override character encoding.
       @return The encoding selected by the user or an empty string if auto-detection
@@ -313,20 +316,20 @@ public:
 
     void resetStateForNewMessage();
 
-    void setMessageInternal(const KMime::Message::Ptr &message, UpdateMode updateMode);
+    void setMessageInternal(const KMime::Message::Ptr &message, MimeTreeParser::UpdateMode updateMode);
 
     /** Set the Akonadi item that will be displayed.
     *  @param item - the Akonadi item to be displayed. If it doesn't hold a mail (KMime::Message::Ptr as payload data),
     *                an empty page is shown.
     *  @param updateMode - update the display immediately or not. See MailViewer::UpdateMode.
     */
-    void setMessageItem(const Akonadi::Item &item, UpdateMode updateMode = Delayed);
+    void setMessageItem(const Akonadi::Item &item, MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
 
     /** Set the message that shall be shown.
     * @param msg - the message to be shown. If 0, an empty page is displayed.
     * @param updateMode - update the display immediately or not. See MailViewer::UpdateMode.
     */
-    void setMessage(const KMime::Message::Ptr &msg, UpdateMode updateMode = Delayed);
+    void setMessage(const KMime::Message::Ptr &msg, MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
 
     /** Instead of settings a message to be shown sets a message part
       to be shown */
@@ -339,15 +342,13 @@ public:
     /** View message part of type message/RFC822 in extra viewer window. */
     void atmViewMsg(const KMime::Message::Ptr &message);
 
-    void setExternalWindow(bool b);
-
     void adjustLayout();
     void createWidgets();
     void createActions();
 
     void showContextMenu(KMime::Content *content, const QPoint &point);
 
-    KToggleAction *actionForAttachmentStrategy(const AttachmentStrategy *);
+    KToggleAction *actionForAttachmentStrategy(const MimeTreeParser::AttachmentStrategy *);
     /** Read override codec from configuration */
     void readGlobalOverrideCodec();
 
@@ -357,7 +358,7 @@ public:
 
     QString renderAttachments(KMime::Content *node, const QColor &bgColor) const;
 
-    KMime::Content *findContentByType(KMime::Content *content, const QByteArray &type); //TODO(Andras) move to NodeHelper
+    KMime::Content *findContentByType(KMime::Content *content, const QByteArray &type); //TODO(Andras) move to MimeTreeParser::NodeHelper
 
     /** Return a QTextCodec for the specified charset.
     * This function is a bit more tolerant, than QTextCodec::codecForName */
@@ -402,18 +403,6 @@ public:
 
     void attachmentView(KMime::Content *atmNode);
 
-    /** Return weather to show or hide the full list of "To" addresses */
-    bool showFullToAddressList() const;
-
-    /** Show or hide the full list of "To" addresses */
-    void setShowFullToAddressList(bool showFullToAddressList = true);
-
-    /** Return weather to show or hide the full list of "To" addresses */
-    bool showFullCcAddressList() const;
-
-    /** Show or hide the full list of "To" addresses */
-    void setShowFullCcAddressList(bool showFullCcAddressList = true);
-
     /** Show/Hide the field with id "field" */
     void toggleFullAddressList(const QString &field);
 
@@ -429,6 +418,7 @@ public:
     void setPluginName(const QString &pluginName);
 
     QList<QAction *> viewerPluginActionList(MessageViewer::ViewerPluginInterface::SpecificFeatureTypes features);
+    QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
 
 private Q_SLOTS:
     void slotActivatePlugin(MessageViewer::ViewerPluginInterface *interface);
@@ -467,15 +457,22 @@ private Q_SLOTS:
     void slotServiceUrlSelected(PimCommon::ShareServiceUrlManager::ServiceType serviceType);
     void slotStyleChanged(MessageViewer::HeaderStylePlugin *plugin);
     void slotStyleUpdated();
+    void slotWheelZoomChanged(int numSteps);
+    void slotOpenPrintPreviewDialog();
+    void slotOpenInBrowser();
+    void slotPdfCreated(const QString &filename);
+    void slotPdfFailed();
+    void slotExportHtmlPageFailed();
+    void slotExportHtmlPageSuccess(const QString &filename);
 public Q_SLOTS:
     /** An URL has been activate with a click. */
     void slotUrlOpen(const QUrl &url = QUrl());
 
     /** The mouse has moved on or off an URL. */
-    void slotUrlOn(const QString &link, const QString &title, const QString &textContent);
+    void slotUrlOn(const QString &link);
 
     /** The user presses the right mouse button on an URL. */
-    void slotUrlPopup(const QUrl &, const QUrl &imageUrl, const QPoint &mousePos);
+    void slotUrlPopup(const WebEngineViewer::WebHitTestResult &result);
 
     /** The user selected "Find" from the menu. */
     void slotFind();
@@ -505,7 +502,7 @@ public Q_SLOTS:
       after rendering is finished.
       In the very end it deletes the KMReaderWin window that was created
       for the purpose of rendering. */
-    void slotPrintMsg();
+    void slotPrintMessage();
     void slotPrintPreview();
 
     void slotSetEncoding();
@@ -543,21 +540,17 @@ public Q_SLOTS:
     /** Select message body. */
     void selectAll();
 
-    void clearSelection();
-
     /** Copy URL in mUrlCurrent to clipboard. Removes "mailto:" at
       beginning of URL before copying. */
     void slotUrlCopy();
     void slotSaveMessage();
     /** Re-parse the current message. */
-    void update(MessageViewer::UpdateMode updateMode = Delayed);
+    void update(MimeTreeParser::UpdateMode updateMode = MimeTreeParser::Delayed);
 
     void slotSpeakText();
     void slotCopyImageLocation();
     void slotSaveMessageDisplayFormat();
     void slotResetMessageDisplayFormat();
-    void slotBlockImage();
-    void slotOpenBlockableItems();
 
     void slotGeneralFontChanged();
 
@@ -565,6 +558,8 @@ Q_SIGNALS:
     void showStatusBarMessage(const QString &message);
     void replaceMsgByUnencryptedVersion();
     void popupMenu(const Akonadi::Item &msg, const QUrl &url, const QUrl &imageUrl, const QPoint &mousePos);
+    void displayPopupMenu(const Akonadi::Item &msg, const WebEngineViewer::WebHitTestResult &result, const QPoint &mousePos);
+
     void urlClicked(const Akonadi::Item &msg, const QUrl &url);
     void requestConfigSync();
     void showReader(KMime::Content *aMsgPart, bool aHTML, const QString &encoding);
@@ -575,10 +570,9 @@ Q_SIGNALS:
     void changeDisplayMail(Viewer::DisplayFormatMessage, bool);
     void moveMessageToTrash();
     void executeMailAction(MessageViewer::Viewer::MailAction type);
-
 private:
     QString attachmentInjectionHtml();
-    QString recipientsQuickListLinkHtml(bool, const QString &);
+    QString recipientsQuickListLinkHtml(const QString &);
 
     Akonadi::Relation relatedNoteRelation() const;
     void addHelpTextAction(QAction *act, const QString &text);
@@ -586,7 +580,7 @@ private:
 
     QString picsPath();
 public:
-    NodeHelper *mNodeHelper;
+    MimeTreeParser::NodeHelper *mNodeHelper;
     bool mHtmlMailGlobalSetting;
     bool mHtmlLoadExternalGlobalSetting;
     bool mHtmlLoadExtOverride;
@@ -599,10 +593,10 @@ public:
 #ifndef QT_NO_TREEVIEW
     MimePartTreeView *mMimePartTree;
 #endif
-    MailWebView *mViewer;
-    FindBarWebView *mFindBar;
+    MailWebEngineView *mViewer;
+    WebEngineViewer::FindBarWebEngineView *mFindBar;
 
-    const AttachmentStrategy *mAttachmentStrategy;
+    const MimeTreeParser::AttachmentStrategy *mAttachmentStrategy;
     QTimer mUpdateReaderWinTimer;
     QTimer mResizeTimer;
     QString mOverrideEncoding;
@@ -638,35 +632,32 @@ public:
     KToggleAction *mToggleMimePartTreeAction;
     QAction *mSpeakTextAction;
     QAction *mCopyImageLocation;
-    QAction *mBlockImage;
-    QAction *mBlockableItems;
     QUrl mHoveredUrl;
     QUrl mClickedUrl;
     QUrl mImageUrl;
     QPoint mLastClickPosition;
     bool mCanStartDrag;
-    HtmlWriter *mHtmlWriter;
+    MimeTreeParser::HtmlWriter *mHtmlWriter;
     /** Used only to be able to connect and disconnect finished() signal
       in printMsg() and slotPrintMsg() since mHtmlWriter points only to abstract non-QObject class. */
-    QPointer<WebKitPartHtmlWriter> mPartHtmlWriter;
+    QPointer<WebEnginePartHtmlWriter> mPartHtmlWriter;
 
-    float mSavedRelativePosition;
     int mLevelQuote;
     bool mDecrytMessageOverwrite;
     bool mShowSignatureDetails;
     bool mShowAttachmentQuicklist;
-    bool mExternalWindow;
-    bool mZoomTextOnly;
     int mRecursionCountForDisplayMessage;
     KMime::Content *mCurrentContent;
     KMime::Content *mMessagePartNode;
-    QString mCurrentFileName;
     QString mMessagePath;
+
+    QColor mForegroundError;
+    QColor mBackgroundError;
+
     Viewer *const q;
     bool mShowFullToAddressList;
     bool mShowFullCcAddressList;
     Akonadi::Monitor mMonitor;
-    QString mAppName;
     QSet<AbstractMessageLoadedHandler *> mMessageLoadedHandlers;
     Akonadi::Item::Id mPreviouslyViewedItem;
 
@@ -680,7 +671,7 @@ public:
     MessageViewer::HeaderStylePlugin *mHeaderStylePlugin;
     MessageViewer::HeaderStyleMenuManager *mHeaderStyleMenuManager;
     MessageViewer::ViewerPluginToolManager *mViewerPluginToolManager;
-    MessageViewer::ZoomActionMenu *mZoomActionMenu;
+    WebEngineViewer::ZoomActionMenu *mZoomActionMenu;
 };
 
 }
